@@ -48,39 +48,39 @@
 ##'
 ##' The slope estimate and confidence intervals in the slope are plotted and
 ##' numerical information presented.
-##' 
+##'
 ##' @aliases TheilSen
 ##' @param mydata A data frame containing the field \code{date} and at
 ##'   least one other parameter for which a trend test is required;
 ##'   typically (but not necessarily) a pollutant.
 ##' @param pollutant The parameter for which a trend test is required.
 ##'   Mandatory.
-##' @param deseason Should the data be de-deasonalized first? If 
-##'   \code{TRUE} the function \code{stl} is used (seasonal trend 
+##' @param deseason Should the data be de-deasonalized first? If
+##'   \code{TRUE} the function \code{stl} is used (seasonal trend
 ##'   decomposition using loess). Note that if \code{TRUE} missing
 ##'   data are first linearly interpolated because \code{stl} cannot
 ##'   handle missing data.
 ##' @param type \code{type} determines how the data are split i.e.
-##'   conditioned, and then plotted. The default is will produce a 
+##'   conditioned, and then plotted. The default is will produce a
 ##'   single plot using the entire data. Type can be one of the
 ##'   built-in types as detailed in \code{cutData} e.g.
 ##'   \dQuote{season}, \dQuote{year}, \dQuote{weekday} and so on. For
 ##'   example, \code{type = "season"} will produce four plots --- one
 ##'   for each season.
-##'   
+##'
 ##'   It is also possible to choose \code{type} as another variable in
 ##'   the data frame. If that variable is numeric, then the data will
-##'   be split into four quantiles (if possible) and labelled 
+##'   be split into four quantiles (if possible) and labelled
 ##'   accordingly. If type is an existing character or factor
 ##'   variable, then those categories/levels will be used directly.
 ##'   This offers great flexibility for understanding the variation of
 ##'   different variables and how they depend on one another.
-##'   
-##'   Type can be up length two e.g. \code{type = c("season", 
+##'
+##'   Type can be up length two e.g. \code{type = c("season",
 ##'   "weekday")} will produce a 2x2 plot split by season and day of
-##'   the week. Note, when two types are provided the first forms the 
+##'   the week. Note, when two types are provided the first forms the
 ##'   columns and the second the rows.
-##' @param avg.time Can be \dQuote{month} (the default), 
+##' @param avg.time Can be \dQuote{month} (the default),
 ##'   \dQuote{season} or \dQuote{year}. Determines the time over which
 ##'   data should be averaged. Note that for \dQuote{year}, six or
 ##'   more years are required. For \dQuote{season} the data are split
@@ -89,9 +89,9 @@
 ##' @param statistic Statistic used for calculating monthly values.
 ##'   Default is \dQuote{mean}, but can also be \dQuote{percentile}.
 ##'   See \code{timeAverage} for more details.
-##' @param percentile Single percentile value to use if 
+##' @param percentile Single percentile value to use if
 ##'   \code{statistic = "percentile"} is chosen.
-##' @param data.thresh The data capture threshold to use (%) when 
+##' @param data.thresh The data capture threshold to use (%) when
 ##'   aggregating the data using \code{avg.time}. A value of zero
 ##'   means that all available data will be used in a particular
 ##'   period regardless if of the number of values available.
@@ -108,46 +108,46 @@
 ##'   information should be printed at, default 0.99.
 ##' @param lab.cex Size of text for trend information.
 ##' @param x.relation This determines how the x-axis scale is plotted.
-##'   \dQuote{same} ensures all panels use the same scale and 
-##'   \dQuote{free} will use panel-specfic scales. The latter is a 
+##'   \dQuote{same} ensures all panels use the same scale and
+##'   \dQuote{free} will use panel-specfic scales. The latter is a
 ##'   useful setting when plotting data with very different values.
 ##' @param y.relation This determines how the y-axis scale is plotted.
-##'   \dQuote{same} ensures all panels use the same scale and 
-##'   \dQuote{free} will use panel-specfic scales. The latter is a 
+##'   \dQuote{same} ensures all panels use the same scale and
+##'   \dQuote{free} will use panel-specfic scales. The latter is a
 ##'   useful setting when plotting data with very different values.
 ##' @param data.col Colour name for the data
-##' @param trend list containing information on the line width, line 
-##'   type and line colour for the main trend line and confidence 
+##' @param trend list containing information on the line width, line
+##'   type and line colour for the main trend line and confidence
 ##'   intervals respectively.
 ##' @param text.col Colour name for the slope/uncertainty numeric
 ##'   estimates
 ##' @param slope.text The text shown for the slope (default is
 ##'   \sQuote{units/year}).
-##' @param cols Predefined colour scheme, currently only enabled for 
+##' @param cols Predefined colour scheme, currently only enabled for
 ##'   \code{"greyscale"}.
-##' @param shade The colour used for marking alternate years. Use 
+##' @param shade The colour used for marking alternate years. Use
 ##'   \dQuote{white} or \dQuote{transparent} to remove shading.
-##' @param auto.text Either \code{TRUE} (default) or \code{FALSE}. If 
+##' @param auto.text Either \code{TRUE} (default) or \code{FALSE}. If
 ##'   \code{TRUE} titles and axis labels will automatically try and
 ##'   format pollutant names and units properly e.g.  by subscripting
 ##'   the \sQuote{2} in NO2.
-##' @param autocor Should autocorrelation be considered in the trend 
+##' @param autocor Should autocorrelation be considered in the trend
 ##'   uncertainty estimates? The default is \code{FALSE}. Generally,
 ##'   accounting for autocorrelation increases the uncertainty of the
 ##'   trend estimate --- sometimes by a large amount.
-##' @param slope.percent Should the slope and the slope uncertainties 
-##'   be expressed as a percentage change per year? The default is 
+##' @param slope.percent Should the slope and the slope uncertainties
+##'   be expressed as a percentage change per year? The default is
 ##'   \code{FALSE} and the slope is expressed as an average units/year
-##'   change e.g. ppb.  Percentage changes can often be confusing and 
-##'   should be clearly defined.  Here the percentage change is 
-##'   expressed as 100 * (C.end/C.start - 1) / (end.year - 
-##'   start.year). Where C.start is the concentration at the start 
+##'   change e.g. ppb.  Percentage changes can often be confusing and
+##'   should be clearly defined.  Here the percentage change is
+##'   expressed as 100 * (C.end/C.start - 1) / (end.year -
+##'   start.year). Where C.start is the concentration at the start
 ##'   date and C.end is the concentration at the end date.
-##'   
+##'
 ##'   For \code{avg.time = "year"} (end.year - start.year) will be the
 ##'   total number of years - 1. For example, given a concentration in
 ##'   year 1 of 100 units and a percentage reduction of 5%/yr, after 5
-##'   years there will be 75 units but the actual time span will be 6 
+##'   years there will be 75 units but the actual time span will be 6
 ##'   years i.e. year 1 is used as a reference year. Things are
 ##'   slightly different for monthly values e.g.  \code{avg.time =
 ##'   "month"}, which will use the total number of months as a basis
@@ -155,9 +155,9 @@
 ##'   years.  There can be slight differences in the %/yr trend
 ##'   estimate therefore, depending on whether monthly or annual
 ##'   values are considered.
-##' @param date.breaks Number of major x-axis intervals to use. The 
+##' @param date.breaks Number of major x-axis intervals to use. The
 ##'   function will try and choose a sensible number of dates/times as
-##'   well as formatting the date/time appropriately to the range 
+##'   well as formatting the date/time appropriately to the range
 ##'   being considered. This does not always work as desired
 ##'   automatically. The user can therefore increase or decrease the
 ##'   number of intervals by adjusting the value of \code{date.breaks}
@@ -179,11 +179,11 @@
 ##'   retained, e.g. using \code{output <- TheilSen(mydata, "nox")},
 ##'   this output can be used to recover the data, reproduce or rework
 ##'   the original plot or undertake further analysis.
-##'   
+##'
 ##'   An openair output can be manipulated using a number of generic
 ##'   operations, including \code{print}, \code{plot} and
 ##'   \code{summary}.
-##'   
+##'
 ##'   The \code{data} component of the \code{TheilSen} output includes
 ##'   two subsets: \code{main.data}, the monthly data \code{res2} the
 ##'   trend statistics. For \code{output <- TheilSen(mydata, "nox")},
@@ -245,430 +245,483 @@
 ##' \dontrun{TheilSen(selectByDate(mydata, year = 2000:2005), pollutant = "o3", ylab = "o3 (ppb)")}
 ##'
 ##'
-TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE, 
+TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
                      type = "default", avg.time = "month",
                      statistic = "mean", percentile = NA, data.thresh = 0, alpha = 0.05,
                      dec.place = 2, xlab = "year", lab.frac = 0.99, lab.cex = 0.8,
                      x.relation = "same", y.relation = "same", data.col = "cornflowerblue",
                      trend = list(lty = c(1, 5), lwd = c(2, 1), col = c("red", "red")),
-                     text.col = "darkgreen", slope.text = NULL, cols = NULL, 
+                     text.col = "darkgreen", slope.text = NULL, cols = NULL,
                      shade = "grey95", auto.text = TRUE,
-                     autocor = FALSE, slope.percent = FALSE, date.breaks = 7,...)  {
-  
+                     autocor = FALSE, slope.percent = FALSE, date.breaks = 7, ...) {
+
   ## get rid of R check annoyances
-  a = b = lower.a = lower.b = upper.a = upper.b = slope.start = date.end = intercept.start = date.start = lower.start = intercept.lower.start = upper.start = intercept.upper.start = NULL
-  
+  a <- b <- lower.a <- lower.b <- upper.a <- upper.b <- slope.start <- date.end <- intercept.start <- date.start <- lower.start <- intercept.lower.start <- upper.start <- intercept.upper.start <- NULL
+
   ## set graphics
   current.strip <- trellis.par.get("strip.background")
   current.font <- trellis.par.get("fontsize")
-  
+
   ## reset graphic parameters
-  on.exit(trellis.par.set(strip.background = current.strip,
-                          fontsize = current.font))
-  
+  on.exit(trellis.par.set(
+    strip.background = current.strip,
+    fontsize = current.font
+  ))
+
   ## greyscale handling
   if (length(cols) == 1 && cols == "greyscale") {
-    
     trellis.par.set(list(strip.background = list(col = "white")))
     ## other local colours
     trend$col <- c("black", "black")
     data.col <- "darkgrey"
     text.col <- "black"
   } else {
-    
     data.col <- data.col
     text.col <- text.col
   }
-  
+
   ## extra.args setup
   extra.args <- list(...)
-  
+
   ## label controls
   ## (xlab currently handled in plot because unqiue action)
-  extra.args$ylab <- if ("ylab" %in% names(extra.args))
-    quickText(extra.args$ylab, auto.text) else quickText(pollutant, auto.text)
-  
-  extra.args$main <- if ("main" %in% names(extra.args))
-    quickText(extra.args$main, auto.text) else quickText("", auto.text)
-  
-  if ("fontsize" %in% names(extra.args))
+  extra.args$ylab <- if ("ylab" %in% names(extra.args)) {
+    quickText(extra.args$ylab, auto.text)
+  } else {
+    quickText(pollutant, auto.text)
+  }
+
+  extra.args$main <- if ("main" %in% names(extra.args)) {
+    quickText(extra.args$main, auto.text)
+  } else {
+    quickText("", auto.text)
+  }
+
+  if ("fontsize" %in% names(extra.args)) {
     trellis.par.set(fontsize = list(text = extra.args$fontsize))
-  
-  xlim <- if ("xlim" %in% names(extra.args))
-    extra.args$xlim else  NULL
-  
+  }
+
+  xlim <- if ("xlim" %in% names(extra.args)) {
+    extra.args$xlim
+  } else {
+    NULL
+  }
+
   ## layout default
-  if(!"layout" %in% names(extra.args))
+  if (!"layout" %in% names(extra.args)) {
     extra.args$layout <- NULL
-  
+  }
+
   vars <- c("date", pollutant)
-  
-  
-  if (!avg.time %in% c("year", "month", "season")) 
-    stop ("avg.time can only be 'month', 'season' or 'year'.")
-  
+
+
+  if (!avg.time %in% c("year", "month", "season")) {
+    stop("avg.time can only be 'month', 'season' or 'year'.")
+  }
+
   ## find time interval
-  # need this because if user has a data capture threshold, need to know 
+  # need this because if user has a data capture threshold, need to know
   # original time interval
   # Working this out for unique dates for all data is what is done here.
   # More reliable than trying to work it out after conditioning where there
   # may be too few data for the calculation to be reliable
   interval <- find.time.interval(mydata$date)
-  
+
   ## equivalent number of days, used to refine interval for month/year
   days <- as.numeric(strsplit(interval, split = " ")[[1]][1]) /
     24 / 3600
-  
+
   ## better interval, most common interval in a year
   if (days == 31) interval <- "month"
   if (days %in% c(365, 366)) interval <- "year"
-  
+
   ## data checks
   mydata <- checkPrep(mydata, vars, type, remove.calm = FALSE)
-  
+
   ## date formatting for plot
   date.at <- as_date(dateBreaks(mydata$date, date.breaks)$major)
   date.format <- dateBreaks(mydata$date)$format
-  
-  
+
+
   ## cutData depending on type
   mydata <- cutData(mydata, type, ...)
-  
+
   ## for overall data and graph plotting
   start.year <- startYear(mydata$date)
-  end.year <-   endYear(mydata$date)
-  start.month <-  startMonth(mydata$date)
-  end.month <-   endMonth(mydata$date)
-  
-  mydata <- timeAverage(mydata, type = type, 
-                        avg.time = avg.time, 
-                        statistic = statistic, 
-                        percentile = percentile,
-                        data.thresh = data.thresh,
-                        interval = interval)
-  
+  end.year <- endYear(mydata$date)
+  start.month <- startMonth(mydata$date)
+  end.month <- endMonth(mydata$date)
+
+  mydata <- timeAverage(mydata,
+    type = type,
+    avg.time = avg.time,
+    statistic = statistic,
+    percentile = percentile,
+    data.thresh = data.thresh,
+    interval = interval
+  )
+
   # timeAverage drops type if default
   if ("default" %in% type) mydata$default <- "default"
-  
-  
+
+
   process.cond <- function(mydata) {
-    
-    if (all(is.na(mydata[[pollutant]]))) return()       
-    
+    if (all(is.na(mydata[[pollutant]]))) return()
+
     ## sometimes data have long trailing NAs, so start and end at
     ## first and last data
     min.idx <- min(which(!is.na(mydata[, pollutant])))
     max.idx <- max(which(!is.na(mydata[, pollutant])))
     mydata <- mydata[min.idx:max.idx, ]
-    
+
     ## these subsets may have different dates to overall
-    start.year <-  startYear(mydata$date)
-    end.year <-   endYear(mydata$date)
-    start.month <-  startMonth(mydata$date)
-    end.month <-   endMonth(mydata$date)
-    
+    start.year <- startYear(mydata$date)
+    end.year <- endYear(mydata$date)
+    start.month <- startMonth(mydata$date)
+    end.month <- endMonth(mydata$date)
+
     if (avg.time == "month") {
-      
       mydata$date <- as_date(mydata$date)
-      
+
       deseas <- mydata[[pollutant]]
-      
+
       ## can't deseason less than 2 years of data
       if (nrow(mydata) <= 24) deseason <- FALSE
-      
+
       if (deseason) {
         ## interpolate missing data
-        mydata[[pollutant]] <- approx(mydata[[pollutant]], 
-                                      n = length(mydata[[pollutant]]))$y
-        
-        myts <- ts(mydata[[pollutant]], start = c(start.year, start.month),
-                   end = c(end.year, end.month), frequency = 12)
+        mydata[[pollutant]] <- approx(mydata[[pollutant]],
+          n = length(mydata[[pollutant]])
+        )$y
+
+        myts <- ts(mydata[[pollutant]],
+          start = c(start.year, start.month),
+          end = c(end.year, end.month), frequency = 12
+        )
         ## key thing is to allow the seanonal cycle to vary, hence
         ## s.window should not be "periodic"; set quite high to avoid
         ## overly fitted seasonal cycle
         ## robustness also makes sense for sometimes noisy data
         ssd <- stl(myts, s.window = 35, robust = TRUE, s.degree = 0)
-        
+
         deseas <- ssd$time.series[, "trend"] + ssd$time.series[, "remainder"]
-        
+
         deseas <- as.vector(deseas)
       }
-      
-      all.results <- data.frame(date = mydata$date, conc = deseas,
-                                stringsAsFactors = FALSE)
+
+      all.results <- data.frame(
+        date = mydata$date, conc = deseas,
+        stringsAsFactors = FALSE
+      )
       results <- na.omit(all.results)
-      
-      
     } else {
-      
+
       ## assume annual
-      all.results <- data.frame(date = as_date(mydata$date), 
-                                conc = mydata[[pollutant]],
-                                stringsAsFactors = FALSE)
+      all.results <- data.frame(
+        date = as_date(mydata$date),
+        conc = mydata[[pollutant]],
+        stringsAsFactors = FALSE
+      )
       results <- na.omit(all.results)
     }
-    
+
     ## now calculate trend, uncertainties etc ###########################
     if (nrow(results) < 6) return(results) ## need enough data to calculate trend
     MKresults <- MKstats(results$date, results$conc, alpha, autocor)
-   
+
     ## make sure missing data are put back in for plotting
     results <- merge(all.results, MKresults, by = "date", all = TRUE)
-   
+
     results
   }
-  
+
   # need to work out how to use dplyr if it does not return a data frame due to too few data
-  split.data <- group_by_(mydata, .dots = type)%>%
+  split.data <- group_by(mydata, UQS(syms(type))) %>%
     do(process.cond(.))
-  
+
 
   if (nrow(split.data) < 2) return()
-  
-  
+
+
   ## special wd layout
-  #(type field in results.grid called type not wd)
+  # (type field in results.grid called type not wd)
   if (length(type) == 1 &
-      type[1] == "wd" & is.null(extra.args$layout)) {
+    type[1] == "wd" & is.null(extra.args$layout)) {
     ## re-order to make sensible layout
     ## starting point code as of ManKendall
-    wds <-  c("NW", "N", "NE", "W", "E", "SW", "S", "SE")
+    wds <- c("NW", "N", "NE", "W", "E", "SW", "S", "SE")
     split.data$wd <- ordered(split.data$wd, levels = wds)
     wd.ok <-
-      sapply(wds, function (x) {
-        if (x %in% unique(split.data$wd))
+      sapply(wds, function(x) {
+        if (x %in% unique(split.data$wd)) {
           FALSE
-        else
+        } else {
           TRUE
+        }
       })
     skip <- c(wd.ok[1:4], TRUE, wd.ok[5:8])
     split.data$wd <- factor(split.data$wd)
     extra.args$layout <- c(3, 3)
-    if (!"skip" %in% names(extra.args))
+    if (!"skip" %in% names(extra.args)) {
       extra.args$skip <- skip
+    }
   }
-  if(!"skip" %in% names(extra.args))
+  if (!"skip" %in% names(extra.args)) {
     extra.args$skip <- FALSE
-  
+  }
+
   ## proper names of labelling #######################################
   strip.dat <- strip.fun(split.data, type, auto.text)
   strip <- strip.dat[[1]]
   strip.left <- strip.dat[[2]]
   pol.name <- strip.dat[[3]]
-  
+
   #### calculate slopes etc ###########################################
-  
+
   # don't have trend information if <6 rows
-  if (nrow(split.data) < 6)
-    split.data <- mutate(split.data, b = NA, a = NA,
-                         lower.a = NA, upper.a = NA,
-                         lower.b = NA, upper.b = NA,
-                         p.stars = NA)
-  
-  split.data <- transform(split.data, slope = 365 * b, intercept = a,
-                          intercept.lower = lower.a, intercept.upper = upper.a,
-                          lower = 365 * lower.b, upper = 365 * upper.b)
-  
+  if (nrow(split.data) < 6) {
+    split.data <- mutate(split.data,
+      b = NA, a = NA,
+      lower.a = NA, upper.a = NA,
+      lower.b = NA, upper.b = NA,
+      p.stars = NA
+    )
+  }
+
+  split.data <- transform(split.data,
+    slope = 365 * b, intercept = a,
+    intercept.lower = lower.a, intercept.upper = upper.a,
+    lower = 365 * lower.b, upper = 365 * upper.b
+  )
+
   ## aggregated results
-  
-  res2 <- group_by_(split.data, .dots = type, "p.stars") %>% 
+  vars <- c(type, "p.stars")
+
+  res2 <- group_by(split.data, UQS(syms(vars))) %>%
     summarise_all(funs(mean(., na.rm = TRUE)))
-  
+
   ## calculate percentage changes in slope and uncertainties need
   ## start and end dates (in days) to work out concentrations at those
   ## points percentage change defind as 100.(C.end/C.start -1) /
   ## duration
-  
-  start <- group_by_(split.data, .dots = type) %>% 
+
+  start <- group_by(split.data, UQS(syms(type))) %>%
     do(head(., 1))
-  
-  end <- group_by_(split.data, .dots = type) %>% 
+
+  end <- group_by(split.data, UQS(syms(type))) %>%
     do(tail(., 1))
-  
+
   percent.change <- merge(start, end, by = type, suffixes = c(".start", ".end"))
-  
+
   percent.change <-
     transform(percent.change,
-              slope.percent = 100 * 365 *
-                ((slope.start * as.numeric(date.end) / 365 + intercept.start) /
-                   (slope.start * as.numeric(date.start) / 365 + intercept.start) - 1
-                ) /
-                (as.numeric(date.end) - as.numeric(date.start)))
+      slope.percent = 100 * 365 *
+        ((slope.start * as.numeric(date.end) / 365 + intercept.start) /
+          (slope.start * as.numeric(date.start) / 365 + intercept.start) - 1
+        ) /
+        (as.numeric(date.end) - as.numeric(date.start))
+    )
   ## got upper/lower intercepts mixed up To FIX?
   percent.change <-
     transform(percent.change,
-              lower.percent = 100 * 365 *
-                ((lower.start * as.numeric(date.end) / 365 + intercept.lower.start) /
-                   (
-                     lower.start * as.numeric(date.start) / 365 + intercept.lower.start
-                   ) - 1
-                ) /
-                (as.numeric(date.end) - as.numeric(date.start)))
-  
+      lower.percent = 100 * 365 *
+        ((lower.start * as.numeric(date.end) / 365 + intercept.lower.start) /
+          (
+            lower.start * as.numeric(date.start) / 365 + intercept.lower.start
+          ) - 1
+        ) /
+        (as.numeric(date.end) - as.numeric(date.start))
+    )
+
   percent.change <-
     transform(percent.change,
-              upper.percent = 100 * 365 *
-                ((upper.start * as.numeric(date.end) / 365 + intercept.upper.start) /
-                   (
-                     upper.start * as.numeric(date.start) / 365 + intercept.upper.start
-                   ) - 1
-                ) /
-                (as.numeric(date.end) - as.numeric(date.start)))
-  
-  percent.change <- percent.change[ ,  c(type, "slope.percent", 
-                                         "lower.percent", "upper.percent")]
-  
+      upper.percent = 100 * 365 *
+        ((upper.start * as.numeric(date.end) / 365 + intercept.upper.start) /
+          (
+            upper.start * as.numeric(date.start) / 365 + intercept.upper.start
+          ) - 1
+        ) /
+        (as.numeric(date.end) - as.numeric(date.start))
+    )
+
+  percent.change <- percent.change[, c(
+    type, "slope.percent",
+    "lower.percent", "upper.percent"
+  )]
+
   split.data <- merge(split.data, percent.change, by = type)
-  
+
   res2 <- merge(res2, percent.change, by = type)
   ## #################################################################
-  
-  
+
+
   temp <- paste(type, collapse = "+")
   myform <- formula(paste("conc ~ date| ", temp, sep = ""))
-  
+
   gap <- (max(split.data$date) - min(split.data$date)) / 80
   if (is.null(xlim)) xlim <- range(split.data$date) + c(-1 * gap, gap)
-  
-  xyplot.args <- list(x = myform, data = split.data,
-                      xlab = quickText(xlab, auto.text),
-                      par.strip.text = list(cex = 0.8),
-                      as.table = TRUE,
-                      xlim = xlim,
-                      strip = strip,
-                      strip.left = strip.left,
-                      scales = list(x = list(at = date.at, format = date.format,
-                                             relation = x.relation),
-                                    y = list(relation = y.relation, rot = 0)),
-                      
-                      panel = function(x, y, subscripts,...){
-                        ## year shading
-                        panel.shade(split.data, start.year, end.year,
-                                    ylim = current.panel.limits()$ylim, shade)
-                        panel.grid(-1, 0)
-                        
-                        panel.xyplot(x, y, type = "b", col = data.col, ...)
-                        
-                        # sub.dat <- na.omit(split.data[subscripts, ])
-                        sub.dat <- split.data[subscripts, ]
-                      
-                        # need some data to plot, check if enough information to show trend
-                        if (nrow(sub.dat) > 0  && !all(is.na(sub.dat$slope))) {
-                          panel.abline(a = sub.dat[1, "intercept"],
-                                       b = sub.dat[1, "slope"] / 365,
-                                       col = trend$col[1], lwd = trend$lwd[1],
-                                       lty = trend$lty[1])
-                          panel.abline(a = sub.dat[1, "intercept.lower"],
-                                       b = sub.dat[1, "lower"] / 365,
-                                       col = trend$col[2], lwd = trend$lwd[2],
-                                       lty = trend$lty[2])
-                          panel.abline(a = sub.dat[1, "intercept.upper"],
-                                       b = sub.dat[1, "upper"] / 365,
-                                       col = trend$col[2], lwd = trend$lwd[2],
-                                       lty = trend$lty[2])
-                          
-                          ## for text on plot - % trend or not?
-                          slope <- "slope"
-                          lower <- "lower"
-                          upper <- "upper"
-                          units <- "units"
-                          
-                          if (slope.percent) {
-                            slope <- "slope.percent"
-                            lower <- "lower.percent"
-                            upper <- "upper.percent"
-                            units <- "%"
-                          }
-                          
-                          ## allow user defined slope text
-                          if (!is.null(slope.text)) {
-                            
-                            slope.text <- slope.text
-                            
-                          } else {
-                            
-                            slope.text <- paste0(units, "/year")
-                            
-                          }
-                          
-                          ## plot top, middle
-                          panel.text(mean(c(current.panel.limits()$xlim[2], 
-                                            current.panel.limits()$xlim[1])),
-                                     current.panel.limits()$ylim[1] + lab.frac *
-                                       (current.panel.limits()$ylim[2] - 
-                                          current.panel.limits()$ylim[1]),
-                                     paste(round(sub.dat[1, slope], dec.place), " ", "[",
-                                           round(sub.dat[1, lower], dec.place), ", ",
-                                           round(sub.dat[1, upper], dec.place), "] ",
-                                           slope.text, " ", sub.dat[1, "p.stars"], sep = ""),
-                                     cex = lab.cex, adj = c(0.5, 1), col = text.col, font = 2)
-                        }
-                      })
-  
-  #reset for extra.args
-  xyplot.args<- listUpdate(xyplot.args, extra.args)
-  
-  #plot
+
+  xyplot.args <- list(
+    x = myform, data = split.data,
+    xlab = quickText(xlab, auto.text),
+    par.strip.text = list(cex = 0.8),
+    as.table = TRUE,
+    xlim = xlim,
+    strip = strip,
+    strip.left = strip.left,
+    scales = list(
+      x = list(
+        at = date.at, format = date.format,
+        relation = x.relation
+      ),
+      y = list(relation = y.relation, rot = 0)
+    ),
+
+    panel = function(x, y, subscripts, ...) {
+      ## year shading
+      panel.shade(split.data, start.year, end.year,
+        ylim = current.panel.limits()$ylim, shade
+      )
+      panel.grid(-1, 0)
+
+      panel.xyplot(x, y, type = "b", col = data.col, ...)
+
+      # sub.dat <- na.omit(split.data[subscripts, ])
+      sub.dat <- split.data[subscripts, ]
+
+      # need some data to plot, check if enough information to show trend
+      if (nrow(sub.dat) > 0 && !all(is.na(sub.dat$slope))) {
+        panel.abline(
+          a = sub.dat[1, "intercept"],
+          b = sub.dat[1, "slope"] / 365,
+          col = trend$col[1], lwd = trend$lwd[1],
+          lty = trend$lty[1]
+        )
+        panel.abline(
+          a = sub.dat[1, "intercept.lower"],
+          b = sub.dat[1, "lower"] / 365,
+          col = trend$col[2], lwd = trend$lwd[2],
+          lty = trend$lty[2]
+        )
+        panel.abline(
+          a = sub.dat[1, "intercept.upper"],
+          b = sub.dat[1, "upper"] / 365,
+          col = trend$col[2], lwd = trend$lwd[2],
+          lty = trend$lty[2]
+        )
+
+        ## for text on plot - % trend or not?
+        slope <- "slope"
+        lower <- "lower"
+        upper <- "upper"
+        units <- "units"
+
+        if (slope.percent) {
+          slope <- "slope.percent"
+          lower <- "lower.percent"
+          upper <- "upper.percent"
+          units <- "%"
+        }
+
+        ## allow user defined slope text
+        if (!is.null(slope.text)) {
+          slope.text <- slope.text
+        } else {
+          slope.text <- paste0(units, "/year")
+        }
+
+        ## plot top, middle
+        panel.text(mean(c(
+          current.panel.limits()$xlim[2],
+          current.panel.limits()$xlim[1]
+        )),
+        current.panel.limits()$ylim[1] + lab.frac *
+          (current.panel.limits()$ylim[2] -
+            current.panel.limits()$ylim[1]),
+        paste(round(sub.dat[1, slope], dec.place), " ", "[",
+          round(sub.dat[1, lower], dec.place), ", ",
+          round(sub.dat[1, upper], dec.place), "] ",
+          slope.text, " ", sub.dat[1, "p.stars"],
+          sep = ""
+        ),
+        cex = lab.cex, adj = c(0.5, 1), col = text.col, font = 2
+        )
+      }
+    }
+  )
+
+  # reset for extra.args
+  xyplot.args <- listUpdate(xyplot.args, extra.args)
+
+  # plot
   plt <- do.call(xyplot, xyplot.args)
-  
-  
+
+
   ## output ##########################################################
-  
-  if (length(type) == 1) plot(plt) else 
+
+  if (length(type) == 1) {
+    plot(plt)
+  } else {
     plot(useOuterStrips(plt, strip = strip, strip.left = strip.left))
-  
-  newdata <- list(main.data = split.data, res2 = res2, 
-                  subsets = c("main.data", "res2"))
+  }
+
+  newdata <- list(
+    main.data = split.data, res2 = res2,
+    subsets = c("main.data", "res2")
+  )
   output <- list(plot = plt, data = newdata, call = match.call())
   class(output) <- "openair"
-  
+
   invisible(output)
-  
 }
 
 
 
-panel.shade <- function(split.data, start.year, end.year, ylim, 
+panel.shade <- function(split.data, start.year, end.year, ylim,
                         shade = "grey95") {
-  
   x1 <- as.POSIXct(seq(ISOdate(start.year - 6, 1, 1),
-                       ISOdate(end.year + 5, 1, 1), by = "2 years"), "GMT")
+    ISOdate(end.year + 5, 1, 1),
+    by = "2 years"
+  ), "GMT")
   x2 <- as.POSIXct(seq(ISOdate(start.year + 1 - 6, 1, 1),
-                       ISOdate(end.year + 5, 1, 1), by = "2 years"), "GMT")
-  
-  
-  if (class(split.data$date)[1]  == "Date") {x1 <- as_date(x1)
-  x2 <- as_date(x2)
+    ISOdate(end.year + 5, 1, 1),
+    by = "2 years"
+  ), "GMT")
+
+
+  if (class(split.data$date)[1] == "Date") {
+    x1 <- as_date(x1)
+    x2 <- as_date(x2)
   }
-  
+
   rng <- range(split.data$conc, na.rm = TRUE) ## range of data
   y1 <- min(split.data$conc, na.rm = TRUE) - 0.1 * abs(rng[2] - rng[1])
   y2 <- max(split.data$conc, na.rm = TRUE) + 0.1 * abs(rng[2] - rng[1])
-  
+
   ## if user selects specific limits
-  
+
   if (!missing(ylim)) {
     y1 <- ylim[1] - 0.1 * abs(ylim[2] - ylim[1])
     y2 <- ylim[2] + 0.1 * abs(ylim[2] - ylim[1])
   }
-  
+
   sapply(seq_along(x1), function(x) lpolygon(c(x1[x], x1[x], x2[x], x2[x]),
-                                             c(y1, y2, y2, y1),
-                                             col = shade, border = "grey95"))
+      c(y1, y2, y2, y1),
+      col = shade, border = "grey95"
+    ))
 }
 
 MKstats <- function(x, y, alpha, autocor) {
-  
   estimates <- regci(as.numeric(x), y, alpha = alpha, autocor = autocor)$regci
-  
+
   p <- estimates[2, 5]
-  
+
   if (p >= 0.1) stars <- ""
   if (p < 0.1 & p >= 0.05) stars <- "+"
   if (p < 0.05 & p >= 0.01) stars <- "*"
   if (p < 0.01 & p >= 0.001) stars <- "**"
   if (p < 0.001) stars <- "***"
-  
+
   results <-
     data.frame(
       date = x,
